@@ -1,7 +1,7 @@
 class Sth:
 
-    def __init__(self, arr):
-        self.arr = arr
+    def __init__(self):
+        pass
 
     def find(self, arr):
         smallest = arr[0]
@@ -14,11 +14,11 @@ class Sth:
     
         return smallest_index
 
-    def sort(self):
+    def sort(self, arr):
         new_arr = []
 
-        for i in range(len(self.arr)):
-            smallest = self.find(self.arr)
-            new_arr.append(self.arr.pop(smallest))
+        for i in range(len(arr)):
+            smallest = self.find(arr)
+            new_arr.append(arr.pop(smallest))
     
         return new_arr
\ No newline at end of file
